"""SalmAlm configuration constants."""

from .limits import (
    CACHE_TTL,
    COMPACTION_THRESHOLD,
    DEFAULT_MAX_TOKENS,
    INTENT_COMPLEX_MSG,
    INTENT_CONTEXT_DEPTH,
    INTENT_SHORT_MSG,
    REFLECT_SNIPPET_LEN,
)
from .models import FALLBACK_MODELS, MODEL_ALIASES, MODELS, THINKING_BUDGET_MAP
from .paths import (
    AGENTS_FILE,
    AUDIT_DB,
    BASE_DIR,
    CACHE_DB,
    DATA_DIR,
    LOG_FILE,
    MEMORY_DB,
    MEMORY_DIR,
    MEMORY_FILE,
    SOUL_FILE,
    TOOLS_FILE,
    USER_FILE,
    VAULT_FILE,
    WORKSPACE_DIR,
)
